@@ -214,7 +214,8 @@ class PressureTimeseries(MetTimeseries):
 
         return self.convolution
 
-    def find_vortices(self, detection_threshold=5, distance=20, fwhm_factor=6):
+    def find_vortices(self, detection_threshold=5, distance=20, fwhm_factor=6,
+            min_num_points=5):
         """
         Finds distinct peaks in the matched-filter convolution, presumably
         vortex signals
@@ -223,6 +224,7 @@ class PressureTimeseries(MetTimeseries):
             detection_threshold (float, optional): threshold for peak detection
             distance (int, optional): min number of point between peaks
             fwhm_factor (int, optional): when returning vortices, how wide a time window to return
+            min_num_points (int, optional): minimum number of points required
 
         Returns:
             list of times and pressures for each vortex
@@ -252,11 +254,11 @@ class PressureTimeseries(MetTimeseries):
                     fwhm_factor/2*int(self.peak_widths[i]))
 
             # Make sure there are enough points in the vortex
-            if(mx_ind - mn_ind > 5):
+            if(mx_ind - mn_ind > min_num_points):
                 # Use original, unfiltered data
                 self.vortices.append({"time": self.time[mn_ind:mx_ind],
-                    "pressure": self.data[mn_ind:mx_ind],
-                    "pressure_scatter": self.detrended_data_scatter*\
+                    "data": self.data[mn_ind:mx_ind],
+                    "scatter": self.detrended_data_scatter*\
                             np.ones_like(self.time[mn_ind:mx_ind])})
 
         return self.vortices
@@ -297,7 +299,7 @@ class PressureTimeseries(MetTimeseries):
 
             try:
                 popt, unc = utils.fit_vortex(self.vortices[i], init_params, 
-                        bounds, sigma=self.vortices[i]["pressure_scatter"])
+                        bounds, sigma=self.vortices[i]["scatter"])
 
                 self.popts.append(popt)
                 self.uncs.append(unc)
@@ -311,8 +313,8 @@ class PressureTimeseries(MetTimeseries):
 
                     # Remember! Times are in hours!
                     time = self.vortices[i]["time"]
-                    ydata = self.vortices[i]["pressure"] - popt[0]
-                    yerr = self.vortices[i]["pressure_scatter"]
+                    ydata = self.vortices[i]["data"] - popt[0]
+                    yerr = self.vortices[i]["scatter"]
                     model_func = lambda time, popt:\
                             utils.modified_lorentzian(time, *popt) - popt[0]
                     model = utils.plot_vortex(time, 
@@ -357,7 +359,7 @@ class PressureTimeseries(MetTimeseries):
 
         Args:
             vortex (dict of float arrays): vortex["time"] - time, 
-            vortex["pressure"] - pressure
+            vortex["data"] - pressure
             init_* (float): initial parameters
 
         Returns:
@@ -366,7 +368,7 @@ class PressureTimeseries(MetTimeseries):
         """
 
         x = vortex["time"]
-        y = vortex["pressure"]
+        y = vortex["data"]
 
         # Initial fit to background trend
         fit_params = np.polyfit(x, y, 1)
@@ -397,7 +399,7 @@ class PressureTimeseries(MetTimeseries):
 
         Args:
             vortex (dict of float arrays): vortex["time"] - time,
-            vortex["pressure"] - pressure
+            vortex["data"] - pressure
             init_params (float array): initial parameters in following order:
                 init_baseline, init_slope, init_t0, init_DeltaP, init_Gamma
             slope_fac (float): maximum factor for slope upper bound
@@ -409,7 +411,7 @@ class PressureTimeseries(MetTimeseries):
         """
 
         x = vortex["time"]
-        y = vortex["pressure"]
+        y = vortex["data"]
 
        # Initial fit to background trend
         fit_params = np.polyfit(x, y, 1)
@@ -537,9 +539,9 @@ class PressureTimeseries(MetTimeseries):
 
         # Remember! Times are in hours!
         time = self.vortices[which_vortex]["time"]
-        ydata = self.vortices[which_vortex]["pressure"] -\
+        ydata = self.vortices[which_vortex]["data"] -\
                 self.popts[which_vortex][0]
-        yerr = self.vortices[which_vortex]["pressure_scatter"]
+        yerr = self.vortices[which_vortex]["scatter"]
         model = utils.plot_vortex(time, self.popts[which_vortex][2], ydata, 
                 model_func, self.popts[which_vortex], ax4, yerr=yerr)
 
@@ -623,11 +625,55 @@ class PressureTimeseries(MetTimeseries):
         return deltaP_grid, Gamma_grid*3600., detection_statistics
 
 class TemperatureTimeseries(MetTimeseries):
-    def __init__(self, time, temperature_data):
+    def __init__(self, time, temperature_data, 
+            pressure_vortex_popts=None, pressure_vortex_uncs=None):
         """
         Args:
             time (float, array): time of meteorological time-series
             temperature_data (float, array): temperature measurements
+            pressure_vortex_params/uncs (list of float arrays): the best-fit 
+            t0, Delta P, and FWHM values and uncertainties for a set of vortices
+            detected in the pressure time-series collected contemporaneously
         """
         super().__init__(time, temperature_data)
 
+        # The best-fit t0, Delta P, and FWHM values for associated vortices
+        # detected in the contemporaneously collected pressure time-series
+        self.pressure_vortex_popts = pressure_vortex_popts
+        self.pressure_vortex_uncs = pressure_vortex_uncs
+
+        # The temperature vortex signals
+        self.vortices = None
+
+    def retrieve_vortices(self, fwhm_factor=6, min_num_points=5):
+        """
+        Retrieves the times and temperature data corresponding to vortices
+        identified in pressure data
+
+        Args:
+            fwhm_factor (int, optional): when returning vortices, how wide a time window to return
+            min_num_points (int, optional): minimum number of points
+
+        Returns:
+            list of times and temperatures for each vortex
+
+        """
+    
+        if(self.pressure_vortex_popts is None):
+            raise ValueError("self.pressure_vortex_popts is None!")
+
+        self.vortices = []
+
+        for i in range(len(self.pressure_vortex_popts)):
+
+            # Grab all the points within the vortex signal
+            ind = np.abs(self.time - self.pressure_vortex_popts[i][2]) <\
+                    fwhm_factor*self.pressure_vortex_popts[i][4]/2.
+
+            if(len(self.time[ind]) > min_num_points):
+                # Use original, unfiltered data.
+                #
+                # Because the temperature data show so much more red noise
+                # than the pressure data, we do NOT include scatter here.
+                self.vortices.append({"time": self.time[ind],
+                    "data": self.data[ind]})
